import { __awaiter, __decorate } from "tslib";
import { KeyCode } from '@ag-grid-community/core';
import { logger } from '@genesislcap/grid-pro';
import { css, html, observable } from '@microsoft/fast-element';
import { FoundationElement } from '@microsoft/fast-foundation';
import { FDC3 } from './fdc3';
/**
 * The AG Action Renderer Styles.
 * @public
 */
export const fdc3AgActionRendererStyles = css `
  .action-container {
    align-items: center;
    display: flex;
    height: 100%;
    justify-content: center;
  }
  .action-renderer {
    align-self: center;
    display: flex;
    height: calc(
      (var(--base-height-multiplier) + var(--density)) * var(--design-unit) *
        var(--action-height-multiplier)
    );
  }
`;
/**
 * The AG Action Renderer element.
 * @public
 */
export class Fdc3GridActionRaiseIntent extends FoundationElement {
    clickHandler() {
        return __awaiter(this, void 0, void 0, function* () {
            this.pendingAction = true;
            yield this.fdc3.raiseIntent({
                type: this.intentContextType,
                name: this.intentContextType,
                id: this.params.data,
            }, this.intentName);
            this.pendingAction = false;
        });
    }
    init(params) {
        if (!params)
            return;
        this.params = params;
        params.eGridCell.addEventListener('keydown', (event) => {
            if (event.key === KeyCode.ENTER) {
                this.clickHandler();
            }
        });
    }
    getGui() {
        return this;
    }
    refresh(params) {
        this.params = params;
        return true;
    }
    isDisabled(data) {
        var _a;
        if (typeof ((_a = this.params) === null || _a === void 0 ? void 0 : _a.isDisabled) === 'function') {
            try {
                return this.params.isDisabled(data);
            }
            catch (error) {
                logger.error('Error executing grid action cell renderer isDisabled callback:', error);
            }
        }
        return false;
    }
    get dataTestId() {
        var _a;
        if (this.params.dataTestId) {
            return this.params.dataTestId + ((_a = this.params.data[this.params.uniqueFieldName]) !== null && _a !== void 0 ? _a : '');
        }
        return undefined;
    }
}
__decorate([
    FDC3
], Fdc3GridActionRaiseIntent.prototype, "fdc3", void 0);
__decorate([
    observable
], Fdc3GridActionRaiseIntent.prototype, "params", void 0);
__decorate([
    observable
], Fdc3GridActionRaiseIntent.prototype, "pendingAction", void 0);
/**
 * A function that returns a Foundation Action Renderer for configuring the component with a DesignSystem that raises an fdc3 intent.
 *
 * @public
 * @remarks
 * HTML Element: \<foundation-grid-pro-action-raise-intent-renderer\>
 */
export const foundationGridProRaiseIntentActionRenderer = Fdc3GridActionRaiseIntent.compose({
    baseName: 'grid-pro-action-raise-intent-renderer',
    styles: css `
    ${fdc3AgActionRendererStyles}
  `,
    template: html `
    <div class="action-container" part="action-container">
      <foundation-button
        class="action-renderer"
        part="action-renderer"
        data-test-id="${(x) => x.dataTestId}"
        ?disabled=${(x) => { var _a; return x.pendingAction || x.isDisabled((_a = x.params) === null || _a === void 0 ? void 0 : _a.data); }}
        appearance="${(x) => x.params.appearance}"
        @click=${(x) => x.clickHandler()}">${(x) => x.params.actionName}
      </foundation-button>
    </div>`,
});
